Control - Blueye SDK

Skip to content

# Control

## `` control

Classes:

- `ActivateGuestPortsCtrl` –

  Activated the guest port power.

- `ActivateMultibeamCtrl` –

  Activate the multibeam with specified configuration.

- `AutoAltitudeCtrl` –

  Issue a command to set auto altitude to a desired state.

- `AutoDepthCtrl` –

  Issue a command to set auto depth to a desired state.

- `AutoHeadingCtrl` –

  Issue a command to set auto heading to a desired state.

- `AutoPilotHeaveCtrl` –

  Issue a command to set Auto Pilot for vertiacl movement to a

- `AutoPilotSurgeYawCtrl` –

  Issue a command to set Auto Pilot for cruising and turning to

- `CalibrateDvlGyroCtrl` –

  Issue a command to calibrate the DVL gyro.

- `CancelCalibrationCtrl` –

  Issue a command to cancel compass calibration.

- `ClearMissionCtrl` –

  Clear the loaded mission.

- `DeactivateGuestPortsCtrl` –

  Deactivate the guest port power.

- `DeactivateMultibeamCtrl` –

  Deactivate the multibeam.

- `EndDiveCtrl` –

  Message sent when the user hits the end dive button in the

- `FinishCalibrationCtrl` –

  Issue a command to finish compass calibration.

- `GenericServoCtrl` –

  Issue a command to set a generic servo value.

- `GripperCtrl` –

  Issue a command to control the gripper.

- `GuestportLightsCtrl` –

  Issue a command to set the guest port light intensity.

- `LaserCtrl` –

  Issue a command to set the laser intensity.

- `LightsCtrl` –

  Issue a command to set the main light intensity.

- `MotionInputCtrl` –

  Issue a command to move the drone in the surge, sway, heave,

- `MultibeamServoCtrl` –

  Issue a command to set multibeam servo angle.

- `PauseMissionCtrl` –

  Issue a command to pause the loaded mission.

- `PilotGPSPositionCtrl` –

  Issue a command with the GPS position of the pilot.

- `PingerConfigurationCtrl` –

  Issue a command to set the pinger configuration.

- `RecordCtrl` –

  Issue a command to start video recording.

- `ResetOdometerCtrl` –

  Issue a command to reset the odometer.

- `ResetPositionCtrl` –

  Issue a command to reset the position estimate.

- `RestartGuestPortsCtrl` –

  Restart the guest ports by turning power on and off.

- `RunMissionCtrl` –

  Issue a command to start and pause the loaded mission.

- `SetAquaTrollConnectionStatusCtrl` –

  Request to change the In-Situ Aqua Troll connection status.

- `SetAquaTrollParameterUnitCtrl` –

  Request to set an In-Situ Aqua Troll parameter unit.

- `SetMultibeamConfigCtrl` –

  Update the multibeam settings.

- `StartCalibrationCtrl` –

  Issue a command to start compass calibration.

- `StartDiveCtrl` –

  Message sent when the user hits the start dive button in the

- `StationKeepingCtrl` –

  Issue a command to set station keeping to a desired state.

- `SystemTimeCtrl` –

  Issue a command to set the system time on the drone.

- `TakePictureCtrl` –

  Issue a command to take a picture.

- `TiltStabilizationCtrl` –

  Issue a command to enable or disable tilt stabilization.

- `TiltVelocityCtrl` –

  Issue a command to tilt the drone camera.

- `WatchdogCtrl` –

  Issue a watchdog message to indicate that the remote client

- `WaterDensityCtrl` –

  Issue a command to set the water density.

- `WeatherVaningCtrl` –

  Issue a command to set station keeping with weather vaning to

### `` ActivateGuestPortsCtrl

Activated the guest port power.

### `` ActivateMultibeamCtrl

Activate the multibeam with specified configuration.

#### `` config `class-attribute` `instance-attribute`

    config: MultibeamConfig = Field(
        MESSAGE, number=1, message=MultibeamConfig
    )

### `` AutoAltitudeCtrl

Issue a command to set auto altitude to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: AutoAltitudeState = Field(
        MESSAGE, number=1, message=AutoAltitudeState
    )

### `` AutoDepthCtrl

Issue a command to set auto depth to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: AutoDepthState = Field(
        MESSAGE, number=1, message=AutoDepthState
    )

### `` AutoHeadingCtrl

Issue a command to set auto heading to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: AutoHeadingState = Field(
        MESSAGE, number=1, message=AutoHeadingState
    )

### `` AutoPilotHeaveCtrl

Issue a command to set Auto Pilot for vertiacl movement to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: AutoPilotHeaveState = Field(
        MESSAGE, number=1, message=AutoPilotHeaveState
    )

### `` AutoPilotSurgeYawCtrl

Issue a command to set Auto Pilot for cruising and turning to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: AutoPilotSurgeYawState = Field(
        MESSAGE, number=1, message=AutoPilotSurgeYawState
    )

### `` CalibrateDvlGyroCtrl

Issue a command to calibrate the DVL gyro.

### `` CancelCalibrationCtrl

Issue a command to cancel compass calibration.

### `` ClearMissionCtrl

Clear the loaded mission.

### `` DeactivateGuestPortsCtrl

Deactivate the guest port power.

### `` DeactivateMultibeamCtrl

Deactivate the multibeam.

### `` EndDiveCtrl

Message sent when the user hits the end dive button in the app. The message does not do anything, but is included in the log files so we can see at which point the user exited the dive view.

### `` FinishCalibrationCtrl

Issue a command to finish compass calibration.

### `` GenericServoCtrl

Issue a command to set a generic servo value.

#### `` servo `class-attribute` `instance-attribute`

    servo: GenericServo = Field(
        MESSAGE, number=1, message=GenericServo
    )

### `` GripperCtrl

Issue a command to control the gripper.

#### `` gripper_velocities `class-attribute` `instance-attribute`

    gripper_velocities: GripperVelocities = Field(
        MESSAGE, number=1, message=GripperVelocities
    )

### `` GuestportLightsCtrl

Issue a command to set the guest port light intensity.

#### `` lights `class-attribute` `instance-attribute`

    lights: Lights = Field(MESSAGE, number=1, message=Lights)

### `` LaserCtrl

Issue a command to set the laser intensity.

#### `` laser `class-attribute` `instance-attribute`

    laser: Laser = Field(MESSAGE, number=1, message=Laser)

### `` LightsCtrl

Issue a command to set the main light intensity.

#### `` lights `class-attribute` `instance-attribute`

    lights: Lights = Field(MESSAGE, number=1, message=Lights)

### `` MotionInputCtrl

Issue a command to move the drone in the surge, sway, heave, or yaw direction.

#### `` motion_input `class-attribute` `instance-attribute`

    motion_input: MotionInput = Field(
        MESSAGE, number=1, message=MotionInput
    )

### `` MultibeamServoCtrl

Issue a command to set multibeam servo angle.

#### `` servo `class-attribute` `instance-attribute`

    servo: MultibeamServo = Field(
        MESSAGE, number=1, message=MultibeamServo
    )

### `` PauseMissionCtrl

Issue a command to pause the loaded mission.

### `` PilotGPSPositionCtrl

Issue a command with the GPS position of the pilot.

#### `` position `class-attribute` `instance-attribute`

    position: LatLongPosition = Field(
        MESSAGE, number=1, message=LatLongPosition
    )

### `` PingerConfigurationCtrl

Issue a command to set the pinger configuration.

#### `` configuration `class-attribute` `instance-attribute`

    configuration: PingerConfiguration = Field(
        MESSAGE, number=1, message=PingerConfiguration
    )

### `` RecordCtrl

Issue a command to start video recording.

#### `` record_on `class-attribute` `instance-attribute`

    record_on: RecordOn = Field(
        MESSAGE, number=1, message=RecordOn
    )

### `` ResetOdometerCtrl

Issue a command to reset the odometer.

### `` ResetPositionCtrl

Issue a command to reset the position estimate.

#### `` settings `class-attribute` `instance-attribute`

    settings: ResetPositionSettings = Field(
        MESSAGE, number=1, message=ResetPositionSettings
    )

### `` RestartGuestPortsCtrl

Restart the guest ports by turning power on and off.

#### `` restart_info `class-attribute` `instance-attribute`

    restart_info: GuestPortRestartInfo = Field(
        MESSAGE, number=1, message=GuestPortRestartInfo
    )

### `` RunMissionCtrl

Issue a command to start and pause the loaded mission.

### `` SetAquaTrollConnectionStatusCtrl

Request to change the In-Situ Aqua Troll connection status.

#### `` connection_status `class-attribute` `instance-attribute`

    connection_status: SetAquaTrollConnectionStatus = Field(
        MESSAGE, number=1, message=SetAquaTrollConnectionStatus
    )

### `` SetAquaTrollParameterUnitCtrl

Request to set an In-Situ Aqua Troll parameter unit.

#### `` parameter_info `class-attribute` `instance-attribute`

    parameter_info: SetAquaTrollParameterUnit = Field(
        MESSAGE, number=1, message=SetAquaTrollParameterUnit
    )

### `` SetMultibeamConfigCtrl

Update the multibeam settings.

#### `` config `class-attribute` `instance-attribute`

    config: MultibeamConfig = Field(
        MESSAGE, number=1, message=MultibeamConfig
    )

### `` StartCalibrationCtrl

Issue a command to start compass calibration.

### `` StartDiveCtrl

Message sent when the user hits the start dive button in the app. The message does not do anything, but is included in the log files so we can see at which point the user entered the dive view.

### `` StationKeepingCtrl

Issue a command to set station keeping to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: StationKeepingState = Field(
        MESSAGE, number=1, message=StationKeepingState
    )

### `` SystemTimeCtrl

Issue a command to set the system time on the drone.

#### `` system_time `class-attribute` `instance-attribute`

    system_time: SystemTime = Field(
        MESSAGE, number=1, message=SystemTime
    )

### `` TakePictureCtrl

Issue a command to take a picture.

### `` TiltStabilizationCtrl

Issue a command to enable or disable tilt stabilization.

#### `` state `class-attribute` `instance-attribute`

    state: TiltStabilizationState = Field(
        MESSAGE, number=1, message=TiltStabilizationState
    )

### `` TiltVelocityCtrl

Issue a command to tilt the drone camera.

#### `` velocity `class-attribute` `instance-attribute`

    velocity: TiltVelocity = Field(
        MESSAGE, number=1, message=TiltVelocity
    )

### `` WatchdogCtrl

Issue a watchdog message to indicate that the remote client is connected and working as expected. If a watchdog message is not received every second, the drone will turn off lights and other auto functions to indicate that connection with the client has been lost.

#### `` client_id `class-attribute` `instance-attribute`

    client_id: int = Field(UINT32, number=2)

#### `` connection_duration `class-attribute` `instance-attribute`

    connection_duration: ConnectionDuration = Field(
        MESSAGE, number=1, message=ConnectionDuration
    )

### `` WaterDensityCtrl

Issue a command to set the water density.

#### `` density `class-attribute` `instance-attribute`

    density: WaterDensity = Field(
        MESSAGE, number=1, message=WaterDensity
    )

### `` WeatherVaningCtrl

Issue a command to set station keeping with weather vaning to a desired state.

#### `` state `class-attribute` `instance-attribute`

    state: WeatherVaningState = Field(
        MESSAGE, number=1, message=WeatherVaningState
    )